#include <iostream>
#include <algorithm>
#include <vector>
#include <queue>
#include <string>
#include <stack>
#include <iomanip>
#include <ranges>
#include <list>
#include <cassert>

#define endl "\n"
template<class T, class T2> inline bool chkmax(T &x, const T2 &y) { return x < y ? x = y, 1 : 0; }
template<class T, class T2> inline bool chkmin(T &x, const T2 &y) { return x > y ? x = y, 1 : 0; }

using ll = long long;
const ll mod = 1e18 + 7;

#define LAM1(x) [&] (const auto &a) { return x; }
#define LAM2(x) [&] (const auto &a, const auto &b) { return x; }

const ll MAX_N = 5e5 + 10;
ll arr[MAX_N];
ll left[MAX_N];
ll right[MAX_N];
ll maxheight[MAX_N];
ll n;

ll dp[MAX_N];

ll log2_table[MAX_N];
ll st_left[MAX_N][19];
ll st_right[MAX_N][19];

void precompute_log() {
    log2_table[1] = 0;
    for (ll i = 2; i < MAX_N; i++) {
        log2_table[i] = log2_table[i / 2] + 1;
    }
}

void build_sparse_table() {
    for (ll i = 0; i < n; i++) {
        st_left[i][0] = left[i];
    }
    for (ll j = 1; (1 << j) <= n; j++) {
        for (ll i = 0; i + (1 << j) <= n; i++) {
            st_left[i][j] = std::min(st_left[i][j - 1], st_left[i + (1 << (j - 1))][j - 1]);
        }
    }

    for (ll i = 0; i < n; i++) {
        st_right[i][0] = right[i];
    }
    for (ll j = 1; (1 << j) <= n; j++) {
        for (ll i = 0; i + (1 << j) <= n; i++) {
            st_right[i][j] = std::min(st_right[i][j - 1], st_right[i + (1 << (j - 1))][j - 1]);
        }
    }
}

ll left_range_min(ll l, ll r) {
    ll len = r - l + 1;
    ll k = log2_table[len];
    return std::min(st_left[l][k], st_left[r - (1 << k) + 1][k]);
}

ll right_range_min(ll l, ll r) {
    ll len = r - l + 1;
    ll k = log2_table[len];
    return std::min(st_right[l][k], st_right[r - (1 << k) + 1][k]);
}

ll wall_size(ll start, ll end) {
    if ((end - start) % 2 != 0) { return -mod; }
    ll m = (start + end) / 2ll;
    ll len = end - start + 1;
    ll height = len / 2 + 1;
    if (maxheight[m] < height) { return -mod; } 
    return height * height;
}

struct Line {
    ll a, b;

    Line(const ll a, const ll b) : a(a), b(b) { }

    ll eval(const ll x) const {
        return x * a + b;
    }
};

struct LineContainer;
struct LineNode;

std::vector<LineNode*> to_remove[MAX_N];

struct LineNode {
    LineNode *prv, *nxt;
    Line curr;
    LineContainer* par;

    LineNode() : curr(0, 0) {}

    LineNode(LineNode *prv, LineNode *nxt, const ll a, const ll b, LineContainer* par)
    : prv(prv), nxt(nxt), curr(a, b), par(par) { }
    
    ll eval(const ll x) {
        return curr.eval(x);
    }

    void remove();
};

ll find_switch(const Line& x, const Line& y) {
    const auto diff = y.b - x.b;
    const auto delta = x.a - y.a;
    assert(delta != 0);
    return (diff + delta - 1) / delta;
}

int level = 0;

struct LineContainer {
    LineNode *back = nullptr;

    void push_back(const ll a, const ll b) {
        const auto last_back = back;
        back = new LineNode(last_back, nullptr, a, b, this);
        if (last_back) {
            last_back->nxt = back;

            {
                const auto swt = find_switch(last_back->curr, back->curr);
                if (swt <= level) {
                    back->remove();
                } else if(swt < MAX_N) {
                    to_remove[swt].push_back(back);
                }
            }

        }
    }

    ll eval(const ll x) {
        if (!back) {
            return -mod;
        } else {
            return back->eval(x);
        }
    }
};

void LineNode::remove() {
    if (!par) { return; }

    if (prv) {
        prv->nxt = nxt;
    }

    if (nxt) {
        nxt->prv = prv;
    }

    if (prv && nxt) {
        const auto swt = find_switch(prv->curr, nxt->curr);
        if (swt <= level) {
            nxt->remove();
        } else if(swt < MAX_N) {
            to_remove[swt].push_back(nxt);
        }
    }

    if (par->back == this) {
        par->back = prv;
    }
    par = nullptr;
}

struct SegmentTree {
    LineContainer lc[4 * MAX_N];

    void insert(ll curr, ll l, ll r, ll ind, ll a, ll b) {
        if (l <= ind && ind <= r) {
            lc[curr].push_back(a, b);
        }
        if (l == r) {
            return;
        } else if (l > ind || r < ind) { 
            return; 
        }
        ll m = (l + r) / 2;
        insert(curr * 2, l, m, ind, a, b);
        insert(curr * 2 + 1, m + 1, r, ind, a, b);
    }

    ll evaluate(ll curr, ll l, ll r, ll ql, ll qr, ll x) {
        if (ql <= l && r <= qr) {
            return lc[curr].eval(x);
        } else if (ql > r || qr < l) {
            return -mod;
        }
        ll m = (l + r) / 2;
        return std::max(
            evaluate(curr * 2, l, m, ql, qr, x),
            evaluate(curr * 2 + 1, m + 1, r, ql, qr, x)
        );
    }
} st[2];

void solve() { 
    std::cin >> n;
    for (ll i = 0; i < n; i++) {
        std::cin >> arr[i];
        left[i] = arr[i] - i;
        right[i] = arr[i] + i;
        maxheight[i] = std::min({i + 1, n - i, arr[i]});
    }

    precompute_log();
    build_sparse_table();

    for (ll i = 0; i < n; i++) {
        ll l = 0, r = maxheight[i] + 1;
        while (l < r - 1) {
            ll m = (l + r) / 2;
            if (left_range_min(i - m + 1, i) >= m - i) {
                l = m;
            } else {
                r = m;
            }
        }
        maxheight[i] = l;
    }

    for (ll i = 0; i < n; i++) {
        ll l = 0, r = maxheight[i] + 1;
        while (l < r - 1) {
            ll m = (l + r) / 2;
            if (right_range_min(i, i + m - 1) >= m + i) {
                l = m;
            } else {
                r = m;
            }
        }
        maxheight[i] = l;
    }

    st[0].insert(1, 0, MAX_N - 1, 0, 0, 4);

    for (ll i = 0; i < n; i++) {
        const auto new_level = 2 + i;

        while (level <= new_level) {
            for (const auto it : to_remove[level]) {
                it->remove();
            }
            level ++;
        }

        dp[i] = 4;
        if (i != 0) { dp[i] = dp[i - 1] + 4; }

        const auto max_left = [&](){
            ll l = 0, r = i + 1;
            while (l < r - 1) {
                ll m = (l + r) / 2;
                if (maxheight[i - m] >= m + 1) {
                    l = m;
                } else {
                    r = m;
                }
            }
            return i - 2 * l;
        }();

        const auto best = st[i & 1].evaluate(1, 0, MAX_N - 1, max_left, i, 2 + i) + i * i + 4 * i;
        chkmax(dp[i], best);
        st[(i & 1) ^ 1].insert(1, 0, MAX_N - 1, i + 1, -(2 * i + 2), dp[i] + (i + 1) * (i + 1) + 4);

    }

    std::cout << dp[n - 1] / 4 << endl;
}

signed main() {
    std::ios_base::sync_with_stdio(false); std::cin.tie(NULL); std::cout.tie(NULL);
    ll t = 1;
    while (t--) { solve(); }
    return 0;
}
