#include <iostream>
#include <algorithm>
#include <vector>
#include <queue>
#include <string>
#include <stack>
#include <iomanip>
#include <ranges>
#include <list>
#include <cassert>

#define endl "\n"
template<class T, class T2> inline bool chkmax(T &x, const T2 &y) { return x < y ? x = y, 1 : 0; }
template<class T, class T2> inline bool chkmin(T &x, const T2 &y) { return x > y ? x = y, 1 : 0; }

using ll = long long;
const ll mod = 1e18 + 7;

#define LAM1(x) [&] (const auto &a) { return x; }
#define LAM2(x) [&] (const auto &a, const auto &b) { return x; }

const ll MAX_N = 5e5 + 10;
const ll MAX_LOG = 19;
int arr[MAX_N];
int maxheight[MAX_N];
int n;

ll dp[MAX_N];

int log(int x) {
    return 32 - __builtin_clz(x) - 1;
}

ll wall_size(ll start, ll end) {
    if ((end - start) % 2 != 0) { return -mod; }
    ll m = (start + end) / 2ll;
    ll len = end - start + 1;
    ll height = len / 2 + 1;
    if (maxheight[m] < height) { return -mod; } 
    return height * height;
}

struct Line {
    ll a, b;

    Line(const ll a, const ll b) : a(a), b(b) { }

    ll eval(const ll x) const {
        return x * a + b;
    }
};

struct LineContainer;
struct LineNode;

std::vector<LineNode*> to_remove[MAX_N];

struct LineNode {
    LineNode *prv, *nxt;
    Line curr;
    LineContainer* par;

    LineNode() : curr(0, 0) {}

    LineNode(LineNode *prv, LineNode *nxt, const ll a, const ll b, LineContainer* par)
    : prv(prv), nxt(nxt), curr(a, b), par(par) { }
    
    ll eval(const ll x) {
        return curr.eval(x);
    }

    void remove();
};

ll find_switch(const Line& x, const Line& y) {
    const auto diff = y.b - x.b;
    const auto delta = x.a - y.a;
    assert(delta != 0);
    return (diff + delta - 1) / delta;
}

int level = 0;

struct LineContainer {
    LineNode *back = nullptr;

    void push_back(const ll a, const ll b) {
        ll swt = MAX_N;
        if (back && (swt = find_switch(back->curr, Line(a, b))) <= level) { return; }

        const auto last_back = back;
        back = new LineNode(last_back, nullptr, a, b, this);
        if (last_back) {
            last_back->nxt = back;
        }

        if(swt < MAX_N) {
            to_remove[swt].push_back(back);
        }
    }

    ll eval(const ll x) {
        if (!back) {
            return -mod;
        } else {
            return back->eval(x);
        }
    }
};

void LineNode::remove() {
    if (!par) { return; }

    if (prv) {
        prv->nxt = nxt;
    }

    if (nxt) {
        nxt->prv = prv;
    }

    if (prv && nxt) {
        const auto swt = find_switch(prv->curr, nxt->curr);
        if (swt <= level) {
            nxt->remove();
        } else if(swt < MAX_N) {
            to_remove[swt].push_back(nxt);
        }
    }

    if (par->back == this) { par->back = prv; }
    par = nullptr;
}

struct FenwickTree {
    LineContainer lc[MAX_N / 2];

    void insert(int ind, ll a, ll b) {
        ind = MAX_N / 2 - 1 - ind;
        for (; ind < MAX_N / 2; ind = ind | (ind + 1)) {
            lc[ind].push_back(a, b);
        }
    }

    ll evaluate(ll ql, ll x) {
        ll ind = MAX_N / 2 - 1 - ql;
        ll ret = -mod;
        while (ind >= 0) {
            ret = std::max(ret, lc[ind].eval(x));
            ind = (ind & (ind + 1)) - 1;
        }
        return ret;
    }
} st[2];

void solve() { 
    std::cin >> n;
    assert(n <= 500000);
    for (int i = 0; i < n; i++) {
        std::cin >> arr[i];
        assert(1 <= arr[i] && arr[i] <= 1000000000);
        maxheight[i] = std::min({i + 1, n - i, arr[i]});
    }

    std::array<std::array<int, MAX_N>, MAX_LOG> *st_ = new std::array<std::array<int, MAX_N>, MAX_LOG>;
    
    const auto range_min = [&](ll l, ll r) {
        ll len = r - l + 1;
        ll k = log(len);
        return std::min((*st_)[k][l], (*st_)[k][r - (1 << k) + 1]);
    };

    {
        for (ll i = 0; i < n; i++) {
            (*st_)[0][i] = arr[i] - i;
        }
        for (ll j = 1; (1 << j) <= n; j++) {
            for (ll i = 0; i + (1 << j) <= n; i++) {
                (*st_)[j][i] = std::min((*st_)[j - 1][i], (*st_)[j - 1][i + (1 << (j - 1))]);
            }
        }

        for (ll i = 0; i < n; i++) {
            ll l = 0, r = maxheight[i] + 1;
            while (l < r - 1) {
                ll m = (l + r) / 2;
                if (range_min(i - m + 1, i) >= m - i) {
                    l = m;
                } else {
                    r = m;
                }
            }
            maxheight[i] = l;
        }
    }

    {
        for (ll i = 0; i < n; i++) {
            (*st_)[0][i] = arr[i] + i;
        }
        for (ll j = 1; (1 << j) <= n; j++) {
            for (ll i = 0; i + (1 << j) <= n; i++) {
                (*st_)[j][i] = std::min((*st_)[j - 1][i], (*st_)[j - 1][i + (1 << (j - 1))]);
            }
        }

        for (ll i = 0; i < n; i++) {
            ll l = 0, r = maxheight[i] + 1;
            while (l < r - 1) {
                ll m = (l + r) / 2;
                if (range_min(i, i + m - 1) >= m + i) {
                    l = m;
                } else {
                    r = m;
                }
            }
            maxheight[i] = l;
        }
    }

    delete st_;

    st[0].insert(0, 0, 4);

    for (ll i = 0; i < n; i++) {
        const auto new_level = 2 + i;

        while (level <= new_level) {
            for (const auto it : to_remove[level]) {
                it->remove();
            }
            level ++;
        }

        dp[i] = 4;
        if (i != 0) { dp[i] = dp[i - 1] + 4; }

        const auto max_left = [&](){
            ll l = 0, r = i + 1;
            while (l < r - 1) {
                ll m = (l + r) / 2;
                if (maxheight[i - m] >= m + 1) {
                    l = m;
                } else {
                    r = m;
                }
            }
            return i - 2 * l;
        }();

        const auto best = st[i & 1].evaluate(max_left / 2, 2 + i) + i * i + 4 * i;
        chkmax(dp[i], best);
        st[(i & 1) ^ 1].insert((i + 1) / 2, -(2 * i + 2), dp[i] + (i + 1) * (i + 1) + 4);
    }

    std::cout << dp[n - 1] / 4 << endl;
}

signed main() {
    std::ios_base::sync_with_stdio(false); std::cin.tie(NULL); std::cout.tie(NULL);
    ll t = 1;
    while (t--) { solve(); }
    return 0;
}
