#include <iostream>
#include <algorithm>
#include <vector>
#include <queue>
#include <string>
#include <stack>
#include <iomanip>
#include <ranges>

#define endl "\n"
template<class T, class T2> inline bool chkmax(T &x, const T2 &y) { return x < y ? x = y, 1 : 0; }
template<class T, class T2> inline bool chkmin(T &x, const T2 &y) { return x > y ? x = y, 1 : 0; }

using ll = long long;
const ll mod = 1e18 + 7;

#define LAM1(x) [&] (const auto &a) { return x; }
#define LAM2(x) [&] (const auto &a, const auto &b) { return x; }

const ll MAX_N = 2e6 + 10;
ll arr[MAX_N];
ll left[MAX_N];
ll right[MAX_N];
ll maxheight[MAX_N];
ll n;

ll dp[MAX_N];

ll log2_table[MAX_N];
ll st_left[MAX_N][20];
ll st_right[MAX_N][20];

void precompute_log() {
    log2_table[1] = 0;
    for (ll i = 2; i < MAX_N; i++) {
        log2_table[i] = log2_table[i / 2] + 1;
    }
}

void build_sparse_table() {
    for (ll i = 0; i < n; i++) {
        st_left[i][0] = left[i];
    }
    for (ll j = 1; (1 << j) <= n; j++) {
        for (ll i = 0; i + (1 << j) <= n; i++) {
            st_left[i][j] = std::min(st_left[i][j - 1], st_left[i + (1 << (j - 1))][j - 1]);
        }
    }

    for (ll i = 0; i < n; i++) {
        st_right[i][0] = right[i];
    }
    for (ll j = 1; (1 << j) <= n; j++) {
        for (ll i = 0; i + (1 << j) <= n; i++) {
            st_right[i][j] = std::min(st_right[i][j - 1], st_right[i + (1 << (j - 1))][j - 1]);
        }
    }
}

ll left_range_min(ll l, ll r) {
    ll len = r - l + 1;
    ll k = log2_table[len];
    return std::min(st_left[l][k], st_left[r - (1 << k) + 1][k]);
}

ll right_range_min(ll l, ll r) {
    ll len = r - l + 1;
    ll k = log2_table[len];
    return std::min(st_right[l][k], st_right[r - (1 << k) + 1][k]);
}

ll wall_size(ll start, ll end) {
    if ((end - start) % 2 != 0) { return -mod; }
    ll m = (start + end) / 2ll;
    ll len = end - start + 1;
    ll height = len / 2 + 1;
    if (maxheight[m] < height) { return -2 * mod; } 
    return height * height;
}

ll answer() {
    for (ll i = 0; i < n; i ++) {
        left[i] = arr[i] - i;
        right[i] = arr[i] + i;
        maxheight[i] = std::min({i + 1, n - i, arr[i]});
    }

    precompute_log();
    build_sparse_table();

    for (ll i = 0; i < n; i++) {
        ll l = 0, r = maxheight[i] + 1;
        while (l < r - 1) {
            ll m = (l + r) / 2;
            if (left_range_min(i - m + 1, i) >= m - i) {
                l = m;
            } else {
                r = m;
            }
        }
        maxheight[i] = l;
    }

    for (ll i = 0; i < n; i++) {
        ll l = 0, r = maxheight[i] + 1;
        while (l < r - 1) {
            ll m = (l + r) / 2;
            if (right_range_min(i, i + m - 1) >= m + i) {
                l = m;
            } else {
                r = m;
            }
        }
        maxheight[i] = l;
    }

    for (ll i = 0; i < n; i++) {
        dp[i] = 1;
        if (i != 0) { dp[i] = dp[i - 1]; }
        chkmax(dp[i], wall_size(0, i));
        for (ll j = i - 1; j >= 0; j--) {
            const auto sz = wall_size(j + 1, i);
            if (sz == -2 * mod) { break; }
            chkmax(dp[i], dp[j] + wall_size(j + 1, i));
        }
    }

    return dp[n - 1];
}

void solve() { 
    std::cin >> n;
    for (ll i = 0; i < n; i++) {
        std::cin >> arr[i];
    }

    ll ans = answer();
    std::reverse(arr, arr + n);
    ans = std::max(ans, answer());
    std::cout << ans << endl;
}

signed main() {
    std::ios_base::sync_with_stdio(false); std::cin.tie(NULL); std::cout.tie(NULL);
    ll t = 1;
    while (t--) { solve(); }
    return 0;
}
